@@ -23,6 +23,7 @@
 //---------------------------------------------------------------------------
 #include "MediaInfo/Audio/File_Aac.h"
 #include "MediaInfo/Audio/File_Aac_GeneralAudio_Sbr.h"
+#include "MediaInfo/MediaInfo_Config_MediaInfo.h"
 #include <cmath>
 #include <algorithm>
 #include <cstring>
@@ -63,7 +64,7 @@ int8u Aac_k2_Compute(int8u bs_stop_freq, int8u extension_sampling_frequency_inde
 
 //---------------------------------------------------------------------------
 //Helper
-int8u Aac_bands_Compute(bool warp, int8u bands, int8u a0, int8u a1)
+static int8u Aac_bands_Compute(bool warp, int8u bands, int8u a0, int8u a1)
 {
     float div=(float)log(2.0);
     if (warp)
@@ -75,7 +76,7 @@ int8u Aac_bands_Compute(bool warp, int8u bands, int8u a0, int8u a1)
 //---------------------------------------------------------------------------
 // Master frequency band table
 // Computing for bs_freq_scale = 0
-bool Aac_f_master_Compute_0(int8u &num_env_bands_Master, int8u* f_Master, sbr_handler *sbr, int8u  k0, int8u  k2)
+static bool Aac_f_master_Compute_0(int8u &num_env_bands_Master, int8u* f_Master, sbr_handler *sbr, int8u  k0, int8u  k2)
 {
     int8u dk, numBands;
     if (sbr->bs_alter_scale)
@@ -315,6 +316,9 @@ int16u File_Aac::sbr_huff_dec(const sbr_huffman& Table, const char* Name)
 //---------------------------------------------------------------------------
 void File_Aac::sbr_extension_data(size_t End, int8u id_aac, bool crc_flag)
 {
+    if (raw_data_block_Pos>=sbrs.size())
+        sbrs.resize(raw_data_block_Pos+1);
+
     FILLING_BEGIN();
         if (Infos["Format_Settings_SBR"].empty())
         {
@@ -328,6 +332,7 @@ void File_Aac::sbr_extension_data(size_t End, int8u id_aac, bool crc_flag)
                 Infos["Format_Profile"]+=__T(" / LC");
                 Infos["SamplingRate"]+=__T(" / ")+SamplingRate;
             }
+            Infos["Format_Settings"]=__T("Implicit");
             Infos["Format_Settings_SBR"]=__T("Yes (Implicit)");
             Infos["Codec"]=Ztring().From_Local(Aac_audioObjectType(audioObjectType))+__T("-SBR");
 
@@ -351,16 +356,19 @@ void File_Aac::sbr_extension_data(size_t End, int8u id_aac, bool crc_flag)
                 extension_sampling_frequency_index=Aac_AudioSpecificConfig_sampling_frequency_index(extension_sampling_frequency);
             }
 
-            delete sbr;
+            delete sbrs[raw_data_block_Pos];
             sbr=new sbr_handler;
+            sbrs[raw_data_block_Pos]=sbr;
 
             sbr_header();
 
             if (!Aac_Sbr_Compute(sbr, extension_sampling_frequency_index))
             {
-                delete sbr; sbr=NULL;
+                delete sbrs[raw_data_block_Pos]; sbr=sbrs[raw_data_block_Pos]=NULL;
             }
         }
+        else
+            sbr=sbrs[raw_data_block_Pos];
     //~ }
 
     //Parsing
@@ -371,7 +379,7 @@ void File_Aac::sbr_extension_data(size_t End, int8u id_aac, bool crc_flag)
         sbr_data(id_aac);
 
         FILLING_BEGIN();
-            if (MediaInfoLib::Config.ParseSpeed_Get()<0.3)
+            if (Config->ParseSpeed<0.3)
             {
                 Frame_Count_Valid=Frame_Count+1;
                 if (Frame_Count<8)
