@@ -124,10 +124,10 @@ Ztring ToReturn;
     Node_EssenceTrack->Add_Child("essenceTrackType", essenceTrackType);
 
     //essenceTrackIdentifier
-    Node_EssenceTrack->Add_Child_IfNotEmpty(MI, StreamKind, StreamPos, "ID", "essenceTrackIdentifier", "source", "ID (Mediainfo)");
-    Node_EssenceTrack->Add_Child_IfNotEmpty(MI, StreamKind, StreamPos, "UniqueID", "essenceTrackIdentifier", "source", "UniqueID (Mediainfo)");
-    Node_EssenceTrack->Add_Child_IfNotEmpty(MI, StreamKind, StreamPos, "StreamKindID", "essenceTrackIdentifier", "source", "StreamKindID (Mediainfo)");
-    Node_EssenceTrack->Add_Child_IfNotEmpty(MI, StreamKind, StreamPos, "StreamOrder", "essenceTrackIdentifier", "source", "StreamOrder (Mediainfo)");
+    Node_EssenceTrack->Add_Child_IfNotEmpty(MI, StreamKind, StreamPos, "ID", "essenceTrackIdentifier", "source", std::string("ID (Mediainfo)"));
+    Node_EssenceTrack->Add_Child_IfNotEmpty(MI, StreamKind, StreamPos, "UniqueID", "essenceTrackIdentifier", "source", std::string("UniqueID (Mediainfo)"));
+    Node_EssenceTrack->Add_Child_IfNotEmpty(MI, StreamKind, StreamPos, "StreamKindID", "essenceTrackIdentifier", "source", std::string("StreamKindID (Mediainfo)"));
+    Node_EssenceTrack->Add_Child_IfNotEmpty(MI, StreamKind, StreamPos, "StreamOrder", "essenceTrackIdentifier", "source", std::string("StreamOrder (Mediainfo)"));
 
     //essenceTrackStandard
     if (StreamKind==Stream_Video)
@@ -166,7 +166,7 @@ Ztring ToReturn;
 
     //essenceTrackSamplingRate
     if (StreamKind==Stream_Audio)
-        Node_EssenceTrack->Add_Child_IfNotEmpty(MI, Stream_Audio, StreamPos, Audio_SamplingRate, "essenceTrackSamplingRate", "unitsOfMeasure", "Hz");
+        Node_EssenceTrack->Add_Child_IfNotEmpty(MI, Stream_Audio, StreamPos, Audio_SamplingRate, "essenceTrackSamplingRate", "unitsOfMeasure", std::string("Hz"));
 
     //essenceTrackBitDepth
     Node_EssenceTrack->Add_Child_IfNotEmpty(MI, StreamKind, StreamPos, "BitDepth", "essenceTrackBitDepth");
@@ -251,12 +251,15 @@ Ztring ToReturn;
 }
 
 //---------------------------------------------------------------------------
-Ztring Export_PBCore2::Transform(MediaInfo_Internal &MI)
+Ztring Export_PBCore2::Transform(MediaInfo_Internal &MI, version Version)
 {
     Ztring ToReturn;
 
     Node Node_Main("pbcoreInstantiationDocument");
-    Node_Main.Add_Attribute("xsi:schemaLocation", "http://www.pbcore.org/PBCore/PBCoreNamespace.html http://pbcore.org/xsd/pbcore-2.0.xsd");
+    if (Version==Version_2_0)
+        Node_Main.Add_Attribute("xsi:schemaLocation", "http://www.pbcore.org/PBCore/PBCoreNamespace.html http://pbcore.org/xsd/pbcore-2.0.xsd");
+    else
+        Node_Main.Add_Attribute("xsi:schemaLocation", "http://www.pbcore.org/PBCore/PBCoreNamespace.html https://raw.githubusercontent.com/WGBH/PBCore_2.1/master/pbcore-2.1.xsd"); //TODO: better URL
     Node_Main.Add_Attribute("xmlns:xsi", "http://www.w3.org/2001/XMLSchema-instance");
     Node_Main.Add_Attribute("xmlns", "http://www.pbcore.org/PBCore/PBCoreNamespace.html");
 
@@ -336,7 +339,7 @@ Ztring Export_PBCore2::Transform(MediaInfo_Internal &MI)
         Node_Main.Add_Child("instantiationMediaType", PBCore2_MediaType(MI));
 
     //formatFileSize
-    Node_Main.Add_Child_IfNotEmpty(MI, Stream_General, 0, General_FileSize, "instantiationFileSize", "unitsOfMeasure", "bytes");
+    Node_Main.Add_Child_IfNotEmpty(MI, Stream_General, 0, General_FileSize, "instantiationFileSize", "unitsOfMeasure", std::string("bytes"));
 
     //formatTimeStart
     if (!MI.Get(Stream_Video, 0, Video_Delay_Original_String3).empty())
@@ -417,10 +420,11 @@ Ztring Export_PBCore2::Transform(MediaInfo_Internal &MI)
                 Node_Main.Add_Child("instantiationAnnotation", MI.Get(Stream_General, 0, Pos),
                     "annotationType", MI.Get(Stream_General, 0, Pos, Info_Name).To_UTF8());
 
-    ToReturn+=Ztring().From_UTF8(To_XML(Node_Main, 0).c_str());
+    ToReturn+=Ztring().From_UTF8(To_XML(Node_Main, 0, true, true).c_str());
 
     //Carriage return
-    ToReturn.FindAndReplace(__T("\n"), EOL, 0, Ztring_Recursive);
+    if (MediaInfoLib::Config.LineSeparator_Get()!=__T("\n"))
+        ToReturn.FindAndReplace(__T("\n"), MediaInfoLib::Config.LineSeparator_Get(), 0, Ztring_Recursive);
 
     return ToReturn;
 }
